==> jc-1.4.0.tar.gz: java/rmi/server/RMIClassLoader.h <==
// public class java.rmi.server.RMIClassLoader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fcb28b2391b20604 java_rmi_server_RMIClassLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMIClassLoader_H_
#define _JC_java_rmi_server_RMIClassLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoader$sub_refs	_jc_java_rmi_server_RMIClassLoader$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoader$sub_nonrefs	_jc_java_rmi_server_RMIClassLoader$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader$refs	_jc_java_rmi_server_RMIClassLoader$refs;
typedef struct _jc_java_rmi_server_RMIClassLoader$nonrefs	_jc_java_rmi_server_RMIClassLoader$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader$object	_jc_java_rmi_server_RMIClassLoader$object;

typedef struct _jc_java_rmi_server_RMIClassLoader$fields_struct	_jc_java_rmi_server_RMIClassLoader$fields_struct;
typedef const struct _jc_java_rmi_server_RMIClassLoader$vmethods	_jc_java_rmi_server_RMIClassLoader$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoader$vtable	_jc_java_rmi_server_RMIClassLoader$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoader$vtype	_jc_java_rmi_server_RMIClassLoader$vtype;

// Class fields structure
struct _jc_java_rmi_server_RMIClassLoader$fields_struct {
	struct _jc_object	*cacheAnnotations;
	struct _jc_object	*cacheLoaders;
	struct _jc_java_lang_String$object	*defaultAnnotation;
	struct _jc_java_net_URL$object	*defaultCodebase;
	struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object	*defaultLoader;
};
extern _jc_java_rmi_server_RMIClassLoader$fields_struct _jc_java_rmi_server_RMIClassLoader$class_fields;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader$object *);

// Static methods
extern void _jc_java_rmi_server_RMIClassLoader$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader$method$getClassAnnotation$020ff507b131fc12(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_ClassLoader$object *_jc_java_rmi_server_RMIClassLoader$method$getClassLoader$0fd2e29b1654b3ef(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Object$object *_jc_java_rmi_server_RMIClassLoader$method$getSecurityContext$73cf1c78c835c6df(_jc_env *, struct _jc_java_lang_ClassLoader$object *);
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoader$method$loadClass$b46bd9590884d859(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoader$method$loadClass$b9b6af48233790f8(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoader$vmethods {
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMIClassLoader$vmethods	java_rmi_server_RMIClassLoader;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoader$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader$refs {
    _jc_java_rmi_server_RMIClassLoader$sub_refs	java_rmi_server_RMIClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMIClassLoader$sub_nonrefs	java_rmi_server_RMIClassLoader;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoader$object {
	_jc_java_rmi_server_RMIClassLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoader$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoader$vtype _jc_java_rmi_server_RMIClassLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoader$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoader_H_ */

==> jc-1.4.5.tar.gz: java/rmi/server/RMIClassLoader.h <==
// public class java.rmi.server.RMIClassLoader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fcb28b2391b20604 java_rmi_server_RMIClassLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMIClassLoader_H_
#define _JC_java_rmi_server_RMIClassLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoader$sub_refs	_jc_java_rmi_server_RMIClassLoader$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoader$sub_nonrefs	_jc_java_rmi_server_RMIClassLoader$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader$refs	_jc_java_rmi_server_RMIClassLoader$refs;
typedef struct _jc_java_rmi_server_RMIClassLoader$nonrefs	_jc_java_rmi_server_RMIClassLoader$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoader$object	_jc_java_rmi_server_RMIClassLoader$object;

typedef struct _jc_java_rmi_server_RMIClassLoader$fields_struct	_jc_java_rmi_server_RMIClassLoader$fields_struct;
typedef const struct _jc_java_rmi_server_RMIClassLoader$vmethods	_jc_java_rmi_server_RMIClassLoader$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoader$vtable	_jc_java_rmi_server_RMIClassLoader$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoader$vtype	_jc_java_rmi_server_RMIClassLoader$vtype;

// Class fields structure
struct _jc_java_rmi_server_RMIClassLoader$fields_struct {
	struct _jc_object	*cacheAnnotations;
	struct _jc_object	*cacheLoaders;
	struct _jc_java_lang_String$object	*defaultAnnotation;
	struct _jc_java_net_URL$object	*defaultCodebase;
	struct _jc_java_rmi_server_RMIClassLoader__24MyClassLoader$object	*defaultLoader;
};
extern _jc_java_rmi_server_RMIClassLoader$fields_struct _jc_java_rmi_server_RMIClassLoader$class_fields;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RMIClassLoader$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_rmi_server_RMIClassLoader$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoader$method$getClassAnnotation$020ff507b131fc12(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ClassLoader$object *_jc_java_rmi_server_RMIClassLoader$method$getClassLoader$0fd2e29b1654b3ef(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_rmi_server_RMIClassLoader$method$getSecurityContext$73cf1c78c835c6df(_jc_env *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoader$method$loadClass$b46bd9590884d859(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoader$method$loadClass$b9b6af48233790f8(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoader$vmethods {
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMIClassLoader$vmethods	java_rmi_server_RMIClassLoader;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoader$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader$refs {
    _jc_java_rmi_server_RMIClassLoader$sub_refs	java_rmi_server_RMIClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMIClassLoader$sub_nonrefs	java_rmi_server_RMIClassLoader;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoader$object {
	_jc_java_rmi_server_RMIClassLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoader$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoader$vtype _jc_java_rmi_server_RMIClassLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoader$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoader_H_ */
